#
# spec file for package perl-GD
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-GD
Version:        2.56
Release:        1.1
%define cpan_name GD
Summary:        Interface to Gd Graphics Library
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/GD/
Source0:        http://www.cpan.org/authors/id/L/LD/LDS/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
Patch0:         GD-cflags.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::CBuilder)
BuildRequires:  perl(Module::Build) >= 0.420000
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  freetype2-devel
BuildRequires:  gd-devel >= 2.0.28
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  libvpx-devel
BuildRequires:  xorg-x11-devel
Requires:       gd
# MANUAL END

%description
*GD.pm* is a Perl interface to Thomas Boutell's gd graphics library
(version 2.01 or higher; see below). GD allows you to create color drawings
using a large number of graphics primitives, and emit the drawings as PNG
files.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f -print0 | xargs -0 chmod 644
%patch0 -p1

%build
%{__perl} Build.PL installdirs=vendor optimize="%{optflags}"
./Build build flags=%{?_smp_mflags}

%check
# MANUAL no testing (see https://rt.cpan.org/Public/Bug/Display.html?id=85789)
#./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
# MANUAL BEGIN
mv %{buildroot}%{_bindir}/bdftogd{,.perl-gd}
#sed on %{name}.files
# MANUAL END
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc bdf_scripts ChangeLog demos LICENSE Makefile.old README README.QUICKDRAW

%changelog
* Sat Apr 18 2015 coolo@suse.com
- move /usr/bin/bdftogd to bdftogd.perl-gd to avoid conflict with
  gd package
* Tue Apr 14 2015 coolo@suse.com
- updated to 2.56
  see /usr/share/doc/packages/perl-GD/ChangeLog
  2.56	* Fix Makefile.PL so that it works again.
  2.55	* Great simplification of regression framework ought to fix make test problems.
  * Replace ExtUtils::MakeMaker script with Module::Build system
  (just in time for Module::Build to be deprecated).
  * Remove archaic qd.pl (for creating QuickDraw picts) from distribution.
  2.54	Patch from yurly@unet.net to fix image corruption in rotate180 when image height is odd.
  2.53	Points to Gabor Szabo's GD::Simple tutorial, and fix link to repository.
  2.52    Fix regression tests to run on Ubuntu 12.04 64bit.
* Thu Oct 30 2014 darin@darins.net
- Added libtiff-devel and libvpx-devel to fix builds on SLE_12
* Sun Feb  9 2014 coolo@suse.com
- updated to 2.51
  Fix misleading warning message about location of gd.h file.
* Tue Dec 31 2013 coolo@suse.com
- disable test suite - comparing the bits of pngs is not good enough,
  debian and fedora have the same problem and no reaction upstream
  (RT#85789)
* Sat Jul 27 2013 coolo@suse.com
- updated to 2.50
  Fix gdUseFontConfig so that it can be called as a class method.
  Add GitHub information to README.
  Fix compile crash on windows and strawberry (https://rt.cpan.org/Public/Bug/Display.html?id=67990).
  Fix compilation on older perl's without the Newxz macros.
- rebased GD-cflags.patch
* Thu May 26 2011 coolo@novell.com
- do not add break perl structures in overwriting CCFLAGS with invalid
  flags
- regenerate with cpanspec 1.78.04
* Tue May  3 2011 vcizek@novell.com
- update to 2.46
  Added a basic "use" test for GD::Simple
  Corrected license to GPL+ or Artistic
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Jul 19 2010 anicka@suse.cz
- update to 2.45
  * Clarified the GD license. There is now a formal LICENSE file
  in the package.
* Tue Apr  6 2010 coolo@novell.com
- replace tests.tar with test10.png to fix only the test currently
  broken (relying on old libjpeg and libpng behaviour)
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Tue Jul 21 2009 chris@computersalat.de
- update to 2.44
  * GD::Group now installed properly.
  * Quenched compiler warning caused by Newxs() calls.
- 2.43
  * Added "transparent" color to GD::Simple.
  * Fixed Makefile so that GD/Image.pm depends both on GD/Image.pm.PLS and .config.cache
- 2.42
  * Fixed magic number detection to autodetect certain missed jpeg files (thanks to Mike Walker)
- added perl-macros
  o autogen filelist with perl_gen_filelist
* Wed Sep 10 2008 anicka@suse.cz
- update to 2.41
  * Added backend support for grouping features in GD::SVG module.
* Thu Jun 19 2008 anicka@suse.cz
- update to 2.39
  * Makefile.PL will refuse to run if the proper version of
  libgd is unavailable.
  * Fixed bizarre warning about
  /usr/include/gd.h != /usr/include/gd.h.
  * GD/Image.pm did not bring in croak() properly, meaning that
  incorrect error messages are printed out when any of the
  newFromXXX() calls are made.
  * Instructions on using gdAntiAliased with palette images.
  * Some instructions on installation for Windows users.
* Thu Sep 14 2006 anicka@suse.cz
- update to 2.35
  * Doesn't push libpng onto @LIBS unless png support is
    requested.
  * Supports Storable's freeze/thaw via a custom serializer.
  * Remove "scale redefined" message during compilation of
    Polyline.
* Thu Jul 13 2006 anicka@suse.cz
- update to 2.34
  * many bugfixes since 2.30 added
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan  3 2006 anicka@suse.cz
- update to 2.30
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Fri Jul 29 2005 mjancar@suse.cz
- update to 2.25
* Sat Jan 22 2005 ro@suse.de
- update to 2.19, regenerate test pictures
* Tue Aug 24 2004 mjancar@suse.cz
- fix build with updated libpng
* Thu Aug 19 2004 mjancar@suse.cz
- update to 2.16
* Thu Feb 26 2004 mjancar@suse.cz
- update to 2.12
* Tue Jan 20 2004 meissner@suse.de
- regenerate test10.png so the testcases work.
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Thu Jul 24 2003 mjancar@suse.cz
- update to 2.07
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Tue Apr 29 2003 mjancar@suse.cz
- update to version 2.06
- used $RPM_OPT_FLAGS
* Wed Dec 18 2002 prehak@suse.cz
- updated to version 2.05
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Wed Jul 10 2002 prehak@suse.cz
- updated to version 1.40
- fixed some bugs in specfile
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Fri May  3 2002 meissner@suse.de
- %%_lib fixes.
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Wed Jan 30 2002 rvasice@suse.cz
- update to version 1.38
* Tue Sep  4 2001 rvasice@suse.cz
- fix Group tag to Development/Libraries/Perl
* Wed Aug 22 2001 rvasice@suse.cz
- update to version 1.33
- spec file cleanup
* Sun Aug 12 2001 kukuk@suse.de
- Fix path to perl interpreter
* Sat Apr 28 2001 ro@suse.de
- removed Requires and Obsoletes: gd (we have a package of that name)
* Thu Mar 22 2001 ro@suse.de
- use freetype2 with updated gd
- update to 1.32
* Thu Nov 16 2000 pblaha@suse.cz
- fix problem with #include <gd.h>
- and now requires gd
* Wed Nov 15 2000 ro@suse.de
- fixed neededforbuild gdlib -> gd gd-devel
* Wed Nov  8 2000 pblaha@suse.cz
- rename to perl-GD
* Wed Oct  4 2000 pblaha@suse.cz
- updated to new version 1.30
* Tue Aug 22 2000 ro@suse.de
- fixed perl path
* Mon Jul 17 2000 nadvornik@suse.cz
- fixed neededforbuild
* Wed Jul 12 2000 bubnikv@suse.cz
- substitued /usr/local/bin/perl by /usr/bin/perl in some scripts
* Fri Jun  2 2000 nadvornik@suse.cz
- fixed /var/adm/perl-modules/gd
* Fri May 26 2000 bubnikv@suse.cz
- sorted
* Fri May 12 2000 nadvornik@suse.cz
- update to 1.27
- added BuildRoot
* Thu Jan 20 2000 aj@suse.de
- /usr/man -> /usr/share/man
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Sun Jul 11 1999 ro@suse.de
- fixed perl-path
* Tue Jun 15 1999 ro@suse.de
- update to 1.19
* Wed Mar 17 1999 ro@suse.de
- remove .orig with -f
* Wed Mar  3 1999 ro@suse.de
- filelist: use wildcard for arch in perl-path
* Tue Nov 17 1998 ro@suse.de
- adjust paths for perl 5.00502
* Thu Sep 24 1998 ro@suse.de
- respect perl-versions in spec-file-list
* Fri Aug 21 1998 ro@suse.de
- remove .origs in demos-dir
* Sun Jul 26 1998 bs@suse.de
- fixed pathes in perl scripts.
* Tue Feb 10 1998 bs@suse.de
- fixed Check for man pages
* Tue Jan 13 1998 bb@suse.de
  THE LATEST VERSION IS 1.15
  WHAT'S NEW IN 1.15
  - Patches from Ulrich Pfeifer to allow to compile
    correctly with FastCGI
  - Patches from Douglas Wegscheid to avoid multiple defined
    symbol problems under NetBSD
  - Patches from Weinfriend Koenig to fix problems in filled polygons,
    plus new routines for scaling, translating and rotating polygons.
